@@ -51,12 +51,14 @@ def entity_start_end(text: str, en: MessageEntity) -> tuple[str, str] | None:
             return '<span class="spoiler"><span>', '</span></span>'
         case MessageEntityType.TEXT_LINK:
             return f'<a href="{en.url}">', '</a>'
+        case MessageEntityType.URL:
+            return f'<a href="{text}">', '</a>'
         case MessageEntityType.HASHTAG:
             return f'<a href="#{text}">', '</a>'
         case MessageEntityType.MENTION:
             return f'<a href="https://t.me/{text.strip("@")}">', '</a>'
         case MessageEntityType.CUSTOM_EMOJI:
-            # TODO: Download emoji to the right place
+            # This will be replaced later
             return f'<i class="custom-emoji" emoji-src="emoji/{en.custom_emoji_id}">', '</i>'
         case MessageEntityType.PRE:
             lang = en.language
